@@ -31,6 +31,7 @@
 #include "taler-merchant-httpd_config.h"
 #include "taler-merchant-httpd_exchanges.h"
 #include "taler-merchant-httpd_get-orders-ID.h"
+#include "taler-merchant-httpd_get-templates-ID.h"
 #include "taler-merchant-httpd_mhd.h"
 #include "taler-merchant-httpd_private-delete-account-ID.h"
 #include "taler-merchant-httpd_private-delete-instances-ID.h"
@@ -1268,7 +1269,6 @@ url_handler (void *cls,
       .url_prefix = "/tokenfamilies/",
       .method = MHD_HTTP_METHOD_GET,
       .have_id_segment = true,
-      .allow_deleted_instance = true,
       .handler = &TMH_private_get_tokenfamilies_SLUG
     },
     /* DELETE /tokenfamilies/$SLUG/: */
@@ -1276,7 +1276,6 @@ url_handler (void *cls,
       .url_prefix = "/tokenfamilies/",
       .method = MHD_HTTP_METHOD_DELETE,
       .have_id_segment = true,
-      .allow_deleted_instance = true,
       .handler = &TMH_private_delete_token_families_SLUG
     },
     /* PATCH /tokenfamilies/$SLUG/: */
@@ -1284,7 +1283,6 @@ url_handler (void *cls,
       .url_prefix = "/tokenfamilies/",
       .method = MHD_HTTP_METHOD_PATCH,
       .have_id_segment = true,
-      .allow_deleted_instance = true,
       .handler = &TMH_private_patch_token_family_SLUG,
     },
     {
@@ -1414,12 +1412,18 @@ url_handler (void *cls,
       .have_id_segment = true,
       .handler = &TMH_return_static
     },
+    /* GET /templates/$ID/: */
+    {
+      .url_prefix = "/templates/",
+      .method = MHD_HTTP_METHOD_GET,
+      .have_id_segment = true,
+      .handler = &TMH_get_templates_ID
+    },
     /* POST /templates/$ID: */
     {
       .url_prefix = "/templates/",
       .method = MHD_HTTP_METHOD_POST,
       .have_id_segment = true,
-      .allow_deleted_instance = true,
       .handler = &TMH_post_using_templates_ID,
       .max_upload = 1024 * 1024
     },
