@@ -42,7 +42,7 @@
  * #MERCHANT_PROTOCOL_CURRENT and #MERCHANT_PROTOCOL_AGE in
  * merchant_api_config.c!
  */
-#define MERCHANT_PROTOCOL_VERSION "9:0:5"
+#define MERCHANT_PROTOCOL_VERSION "14:0:10"
 
 
 /**
@@ -89,9 +89,23 @@ MH_handler_config (struct TMH_RequestHandler *rh,
   {
     json_t *specs = json_object ();
     json_t *exchanges = json_array ();
+    struct GNUNET_TIME_Absolute a;
+    struct GNUNET_TIME_Timestamp km;
+    char dat[128];
 
     GNUNET_assert (NULL != specs);
     GNUNET_assert (NULL != exchanges);
+    a = GNUNET_TIME_relative_to_absolute (GNUNET_TIME_UNIT_DAYS);
+    /* Round up to next full day to ensure the expiration
+       time does not become a fingerprint! */
+    a = GNUNET_TIME_absolute_round_down (a,
+                                         GNUNET_TIME_UNIT_DAYS);
+    a = GNUNET_TIME_absolute_add (a,
+                                  GNUNET_TIME_UNIT_DAYS);
+    /* => /config response stays at most 48h in caches! */
+    km = GNUNET_TIME_absolute_to_timestamp (a);
+    TALER_MHD_get_date_string (km.abs_time,
+                               dat);
     TMH_exchange_get_trusted (&add_exchange,
                               exchanges);
     for (unsigned int i = 0; i<TMH_num_cspecs; i++)
@@ -102,7 +116,8 @@ MH_handler_config (struct TMH_RequestHandler *rh,
         GNUNET_assert (0 ==
                        json_object_set_new (specs,
                                             cspec->currency,
-                                            TALER_CONFIG_currency_specs_to_json (
+                                            TALER_CONFIG_currency_specs_to_json
+                                            (
                                               cspec)));
     }
     response = TALER_MHD_MAKE_JSON_PACK (
@@ -112,12 +127,21 @@ MH_handler_config (struct TMH_RequestHandler *rh,
                                      specs),
       GNUNET_JSON_pack_array_steal ("exchanges",
                                     exchanges),
-      GNUNET_JSON_pack_string ("implementation",
-                               "urn:net:taler:specs:merchant:c-reference"),
+      GNUNET_JSON_pack_string (
+        "implementation",
+        "urn:net:taler:specs:taler-merchant:c-reference"),
       GNUNET_JSON_pack_string ("name",
                                "taler-merchant"),
       GNUNET_JSON_pack_string ("version",
                                MERCHANT_PROTOCOL_VERSION));
+    GNUNET_break (MHD_YES ==
+                  MHD_add_response_header (response,
+                                           MHD_HTTP_HEADER_EXPIRES,
+                                           dat));
+    GNUNET_break (MHD_YES ==
+                  MHD_add_response_header (response,
+                                           MHD_HTTP_HEADER_CACHE_CONTROL,
+                                           "public,max-age=21600")); /* 6h */
   }
   return MHD_queue_response (connection,
                              MHD_HTTP_OK,
