@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  (C) 2019-2021 Taler Systems SA
+  (C) 2019-2023 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU Affero General Public License as published by the Free Software
@@ -52,6 +52,10 @@ get_instances_ID (struct TMH_MerchantInstance *mi,
           GNUNET_JSON_pack_string (
             "payto_uri",
             wm->payto_uri),
+          GNUNET_JSON_pack_allow_null (
+            GNUNET_JSON_pack_string (
+              "credit_facade_url",
+              wm->credit_facade_url)),
           GNUNET_JSON_pack_data_auto ("h_wire",
                                       &wm->h_wire),
           GNUNET_JSON_pack_data_auto (
@@ -73,6 +77,9 @@ get_instances_ID (struct TMH_MerchantInstance *mi,
                                   ja),
     GNUNET_JSON_pack_string ("name",
                              mi->settings.name),
+    GNUNET_JSON_pack_string (
+      "user_type",
+      TALER_KYCLOGIC_kyc_user_type2s (mi->settings.ut)),
     GNUNET_JSON_pack_allow_null (
       GNUNET_JSON_pack_string ("website",
                                mi->settings.website)),
@@ -88,12 +95,8 @@ get_instances_ID (struct TMH_MerchantInstance *mi,
                                     mi->settings.address),
     GNUNET_JSON_pack_object_incref ("jurisdiction",
                                     mi->settings.jurisdiction),
-    TALER_JSON_pack_amount ("default_max_wire_fee",
-                            &mi->settings.default_max_wire_fee),
-    TALER_JSON_pack_amount ("default_max_deposit_fee",
-                            &mi->settings.default_max_deposit_fee),
-    GNUNET_JSON_pack_uint64 ("default_wire_fee_amortization",
-                             mi->settings.default_wire_fee_amortization),
+    GNUNET_JSON_pack_bool ("use_stefan",
+                           mi->settings.use_stefan),
     GNUNET_JSON_pack_time_rel ("default_wire_transfer_delay",
                                mi->settings.default_wire_transfer_delay),
     GNUNET_JSON_pack_time_rel ("default_pay_delay",
