@@ -406,6 +406,18 @@ add_order (void *cls,
       return;
     }
 
+    if (TALER_amount_is_zero (&order_amount) &&
+        (po->of.wired != TALER_EXCHANGE_YNA_ALL) )
+    {
+      /* If we are actually filtering by wire status,
+         and the order was over an amount of zero,
+         do not return it as wire status is not
+         exactly meaningful for orders over zero. */
+      json_decref (contract_terms);
+      GNUNET_free (order_id);
+      return;
+    }
+
     if (GNUNET_TIME_absolute_is_future (rd.abs_time) &&
         paid)
     {
@@ -687,44 +699,23 @@ TMH_private_get_orders (const struct TMH_RequestHandler *rh,
                                        MHD_HTTP_BAD_REQUEST,
                                        TALER_EC_GENERIC_PARAMETER_MALFORMED,
                                        "wired");
+  po->of.delta = -20;
+  /* deprecated in protocol v12 */
+  TALER_MHD_parse_request_snumber (connection,
+                                   "delta",
+                                   &po->of.delta);
+  /* since protocol v12 */
+  TALER_MHD_parse_request_snumber (connection,
+                                   "limit",
+                                   &po->of.delta);
+  if ( (-MAX_DELTA > po->of.delta) ||
+       (po->of.delta > MAX_DELTA) )
   {
-    const char *delta_str;
-
-    delta_str = MHD_lookup_connection_value (connection,
-                                             MHD_GET_ARGUMENT_KIND,
-                                             "delta");
-    if (NULL == delta_str)
-    {
-      po->of.delta = -20;
-    }
-    else
-    {
-      char dummy;
-      long long ll;
-
-      if (1 !=
-          sscanf (delta_str,
-                  "%lld%c",
-                  &ll,
-                  &dummy))
-      {
-        GNUNET_break_op (0);
-        return TALER_MHD_reply_with_error (connection,
-                                           MHD_HTTP_BAD_REQUEST,
-                                           TALER_EC_GENERIC_PARAMETER_MALFORMED,
-                                           "delta");
-      }
-      po->of.delta = (int64_t) ll;
-      if ( (-MAX_DELTA > po->of.delta) ||
-           (po->of.delta > MAX_DELTA) )
-      {
-        GNUNET_break_op (0);
-        return TALER_MHD_reply_with_error (connection,
-                                           MHD_HTTP_BAD_REQUEST,
-                                           TALER_EC_GENERIC_PARAMETER_MALFORMED,
-                                           "delta");
-      }
-    }
+    GNUNET_break_op (0);
+    return TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_BAD_REQUEST,
+                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
+                                       "delta");
   }
   {
     const char *date_s_str;
@@ -769,43 +760,25 @@ TMH_private_get_orders (const struct TMH_RequestHandler *rh,
       }
     }
   }
+  if (po->of.delta > 0)
+    po->of.start_row = 0;
+  else
+    po->of.start_row = INT64_MAX;
+  /* deprecated in protocol v12 */
+  TALER_MHD_parse_request_number (connection,
+                                  "start",
+                                  &po->of.start_row);
+  /* since protocol v12 */
+  TALER_MHD_parse_request_number (connection,
+                                  "offset",
+                                  &po->of.start_row);
+  if (INT64_MAX < po->of.start_row)
   {
-    const char *start_row_str;
-
-    start_row_str = MHD_lookup_connection_value (connection,
-                                                 MHD_GET_ARGUMENT_KIND,
-                                                 "start");
-    if (NULL == start_row_str)
-    {
-      if (po->of.delta > 0)
-        po->of.start_row = 0;
-      else
-        po->of.start_row = INT64_MAX;
-    }
-    else
-    {
-      char dummy;
-      unsigned long long ull;
-
-      if (1 !=
-          sscanf (start_row_str,
-                  "%llu%c",
-                  &ull,
-                  &dummy))
-        return TALER_MHD_reply_with_error (connection,
-                                           MHD_HTTP_BAD_REQUEST,
-                                           TALER_EC_GENERIC_PARAMETER_MALFORMED,
-                                           "start");
-      po->of.start_row = (uint64_t) ull;
-      if (INT64_MAX < po->of.start_row)
-      {
-        GNUNET_break_op (0);
-        return TALER_MHD_reply_with_error (connection,
-                                           MHD_HTTP_BAD_REQUEST,
-                                           TALER_EC_GENERIC_PARAMETER_MALFORMED,
-                                           "start");
-      }
-    }
+    GNUNET_break_op (0);
+    return TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_BAD_REQUEST,
+                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
+                                       "start");
   }
   po->of.session_id
     = MHD_lookup_connection_value (connection,
