@@ -49,7 +49,7 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
                             struct MHD_Connection *connection,
                             struct TMH_HandlerContext *hc)
 {
-  struct TALER_MERCHANTDB_InstanceSettings is;
+  struct TALER_MERCHANTDB_InstanceSettings is = { 0 };
   struct TALER_MERCHANTDB_InstanceAuthSettings ias;
   const char *auth_token = NULL;
   const char *uts = "business";
@@ -110,6 +110,7 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
                                                 &is.ut))
   {
     GNUNET_break_op (0);
+    GNUNET_JSON_parse_free (spec);
     return TALER_MHD_reply_with_error (connection,
                                        MHD_HTTP_BAD_REQUEST,
                                        TALER_EC_GENERIC_PARAMETER_MALFORMED,
@@ -123,7 +124,10 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
                                  jauth,
                                  &auth_token);
     if (GNUNET_OK != ret)
+    {
+      GNUNET_JSON_parse_free (spec);
       return (GNUNET_NO == ret) ? MHD_YES : MHD_NO;
+    }
   }
 
   /* check 'id' well-formed */
@@ -146,15 +150,19 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
                       0, NULL, 0))
       id_wellformed = false;
     if (! id_wellformed)
+    {
+      GNUNET_JSON_parse_free (spec);
       return TALER_MHD_reply_with_error (connection,
                                          MHD_HTTP_BAD_REQUEST,
                                          TALER_EC_GENERIC_PARAMETER_MALFORMED,
                                          "id");
+    }
   }
 
   if (! TMH_location_object_valid (is.address))
   {
     GNUNET_break_op (0);
+    GNUNET_JSON_parse_free (spec);
     return TALER_MHD_reply_with_error (connection,
                                        MHD_HTTP_BAD_REQUEST,
                                        TALER_EC_GENERIC_PARAMETER_MALFORMED,
@@ -164,6 +172,7 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
   if (! TMH_location_object_valid (is.jurisdiction))
   {
     GNUNET_break_op (0);
+    GNUNET_JSON_parse_free (spec);
     return TALER_MHD_reply_with_error (connection,
                                        MHD_HTTP_BAD_REQUEST,
                                        TALER_EC_GENERIC_PARAMETER_MALFORMED,
@@ -174,6 +183,7 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
        (! TMH_image_data_url_valid (is.logo)) )
   {
     GNUNET_break_op (0);
+    GNUNET_JSON_parse_free (spec);
     return TALER_MHD_reply_with_error (connection,
                                        MHD_HTTP_BAD_REQUEST,
                                        TALER_EC_GENERIC_PARAMETER_MALFORMED,
@@ -189,6 +199,7 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
     {
       if (mi->deleted)
       {
+        GNUNET_JSON_parse_free (spec);
         return TALER_MHD_reply_with_error (connection,
                                            MHD_HTTP_CONFLICT,
                                            TALER_EC_MERCHANT_PRIVATE_POST_INSTANCES_PURGE_REQUIRED,
@@ -231,12 +242,14 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
                                       ==,
                                       is.default_pay_delay)) )
       {
+        GNUNET_JSON_parse_free (spec);
         return TALER_MHD_reply_static (connection,
                                        MHD_HTTP_NO_CONTENT,
                                        NULL,
                                        NULL,
                                        0);
       }
+      GNUNET_JSON_parse_free (spec);
       return TALER_MHD_reply_with_error (connection,
                                          MHD_HTTP_CONFLICT,
                                          TALER_EC_MERCHANT_PRIVATE_POST_INSTANCES_ALREADY_EXISTS,
@@ -304,21 +317,41 @@ TMH_private_post_instances (const struct TMH_RequestHandler *rh,
                                     &mi->merchant_priv,
                                     &mi->settings,
                                     &mi->auth);
-      if (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT != qs)
+      switch (qs)
       {
-        MHD_RESULT ret;
+      case GNUNET_DB_STATUS_HARD_ERROR:
+        {
+          MHD_RESULT ret;
 
-        TMH_db->rollback (TMH_db->cls);
-        if (GNUNET_DB_STATUS_SOFT_ERROR == qs)
-          goto retry;
-        GNUNET_break (0); // FIXME: distinguish better by qs
-        ret = TALER_MHD_reply_with_error (connection,
-                                          MHD_HTTP_CONFLICT,
-                                          TALER_EC_MERCHANT_PRIVATE_POST_INSTANCES_ALREADY_EXISTS,
-                                          is.id);
-        mi->rc = 1;
-        TMH_instance_decref (mi);
-        return ret;
+          TMH_db->rollback (TMH_db->cls);
+          GNUNET_break (0);
+          ret = TALER_MHD_reply_with_error (connection,
+                                            MHD_HTTP_INTERNAL_SERVER_ERROR,
+                                            TALER_EC_GENERIC_DB_STORE_FAILED,
+                                            is.id);
+          mi->rc = 1;
+          TMH_instance_decref (mi);
+          return ret;
+        }
+      case GNUNET_DB_STATUS_SOFT_ERROR:
+        goto retry;
+      case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
+        {
+          MHD_RESULT ret;
+
+          TMH_db->rollback (TMH_db->cls);
+          GNUNET_break (0);
+          ret = TALER_MHD_reply_with_error (connection,
+                                            MHD_HTTP_CONFLICT,
+                                            TALER_EC_MERCHANT_PRIVATE_POST_INSTANCES_ALREADY_EXISTS,
+                                            is.id);
+          mi->rc = 1;
+          TMH_instance_decref (mi);
+          return ret;
+        }
+      case GNUNET_DB_STATUS_SUCCESS_ONE_RESULT:
+        /* handled below */
+        break;
       }
       qs = TMH_db->commit (TMH_db->cls);
       if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
