@@ -42,6 +42,11 @@
  */
 #define MAX_RETRIES 3
 
+/**
+ * Maximum number of inventory products per order.
+ */
+#define MAX_PRODUCTS 1024
+
 /**
  * What is the label under which we find/place the merchant's
  * jurisdiction in the locations list by default?
@@ -303,25 +308,9 @@ struct OrderContext
     const json_t *products;
 
     /**
-     * TODO: Maybe remove this and set it from settings where we serialize
-     *       the order to JSON?
-     *
-     * Information like name, website, email, etc. about the merchant.
+     * Gross amount value of the contract. Used to
+     * compute @e max_stefan_fee.
      */
-    json_t *merchant;
-
-    /**
-     * TODO: Maybe remove this and set it from settings where we serialize
-     *       the order to JSON?
-     *
-     * Merchant's public key
-     */
-    struct TALER_MerchantPublicKeyP merchant_pub;
-
-    /**
-    * Gross amount value of the contract. Used to
-    * compute @e max_stefan_fee.
-    */
     struct TALER_Amount brutto;
 
     /**
@@ -346,6 +335,11 @@ struct OrderContext
      */
     const json_t *extra;
 
+    /**
+     * Minimum age required by the order.
+     */
+    uint32_t minimum_age;
+
   } parse_order;
 
   /**
@@ -423,6 +417,24 @@ struct OrderContext
      * Which product (by offset) is out of stock, UINT_MAX if all were in-stock.
      */
     unsigned int out_of_stock_index;
+
+    /**
+     * Set to a previous claim token *if* @e idempotent
+     * is also true.
+     */
+    struct TALER_ClaimTokenP token;
+
+    /**
+     * Set to true if the order was idempotent and there
+     * was an equivalent one before.
+     */
+    bool idempotent;
+
+    /**
+     * Set to true if the order is in conflict with a
+     * previous order with the same order ID.
+     */
+    bool conflict;
   } execute_order;
 
   struct
@@ -602,11 +614,6 @@ clean_order (void *cls)
     json_decref (oc->set_exchanges.exchanges);
     oc->set_exchanges.exchanges = NULL;
   }
-  if (NULL != oc->parse_order.merchant)
-  {
-    json_decref (oc->parse_order.merchant);
-    oc->parse_order.merchant = NULL;
-  }
   if (NULL != oc->parse_order.fulfillment_message_i18n)
   {
     json_decref (oc->parse_order.fulfillment_message_i18n);
@@ -634,7 +641,6 @@ clean_order (void *cls)
                      oc->parse_request.uuids_length,
                      0);
   json_decref (oc->parse_request.order);
-  /* TODO: Check that all other fields are cleaned up! */
   json_decref (oc->serialize_order.contract);
   GNUNET_free (oc->parse_order.merchant_base_url);
   GNUNET_free (oc);
@@ -661,6 +667,45 @@ execute_transaction (struct OrderContext *oc)
     GNUNET_break (0);
     return GNUNET_DB_STATUS_HARD_ERROR;
   }
+
+  /* Test if we already have an order with this id */
+  {
+    json_t *contract_terms;
+    struct TALER_MerchantPostDataHashP orig_post;
+
+    qs = TMH_db->lookup_order (TMH_db->cls,
+                               oc->hc->instance->settings.id,
+                               oc->parse_order.order_id,
+                               &oc->execute_order.token,
+                               &orig_post,
+                               &contract_terms);
+    /* If yes, check for idempotency */
+    if (0 > qs)
+    {
+      GNUNET_break (0);
+      TMH_db->rollback (TMH_db->cls);
+      return qs;
+    }
+    if (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT == qs)
+    {
+      TMH_db->rollback (TMH_db->cls);
+      json_decref (contract_terms);
+      /* Comparing the contract terms is sufficient because all the other
+         params get added to it at some point. */
+      if (0 == GNUNET_memcmp (&orig_post,
+                              &oc->parse_request.h_post_data))
+      {
+        GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                    "Order creation idempotent\n");
+        oc->execute_order.idempotent = true;
+        return qs;
+      }
+      GNUNET_break_op (0);
+      oc->execute_order.conflict = true;
+      return qs;
+    }
+  }
+
   /* Setup order */
   qs = TMH_db->insert_order (TMH_db->cls,
                              oc->hc->instance->settings.id,
@@ -757,70 +802,6 @@ execute_order (struct OrderContext *oc)
     &oc->hc->instance->settings;
   enum GNUNET_DB_QueryStatus qs;
 
-  /* Test if we already have an order with this id */
-  /* FIXME: this should be done within the main
-     transaction! */
-  {
-    struct TALER_ClaimTokenP token;
-    json_t *contract_terms;
-    struct TALER_MerchantPostDataHashP orig_post;
-
-    TMH_db->preflight (TMH_db->cls);
-    qs = TMH_db->lookup_order (TMH_db->cls,
-                               oc->hc->instance->settings.id,
-                               oc->parse_order.order_id,
-                               &token,
-                               &orig_post,
-                               &contract_terms);
-    /* If yes, check for idempotency */
-    if (0 > qs)
-    {
-      GNUNET_break (0);
-      TMH_db->rollback (TMH_db->cls);
-      reply_with_error (oc,
-                        MHD_HTTP_INTERNAL_SERVER_ERROR,
-                        TALER_EC_GENERIC_DB_FETCH_FAILED,
-                        "lookup_order");
-      return;
-    }
-    if (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT == qs)
-    {
-      MHD_RESULT ret;
-
-      json_decref (contract_terms);
-      /* Comparing the contract terms is sufficient because all the other
-         params get added to it at some point. */
-      if (0 == GNUNET_memcmp (&orig_post,
-                              &oc->parse_request.h_post_data))
-      {
-        GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                    "Order creation idempotent\n");
-        ret = TALER_MHD_REPLY_JSON_PACK (
-          oc->connection,
-          MHD_HTTP_OK,
-          GNUNET_JSON_pack_string ("order_id",
-                                   oc->parse_order.order_id),
-          GNUNET_JSON_pack_allow_null (
-            GNUNET_JSON_pack_data_varsize (
-              "token",
-              GNUNET_is_zero (&token)
-              ? NULL
-              : &token,
-              sizeof (token))));
-        finalize_order (oc,
-                        ret);
-        return;
-      }
-      /* This request is not idempotent */
-      GNUNET_break_op (0);
-      reply_with_error (
-        oc,
-        MHD_HTTP_CONFLICT,
-        TALER_EC_MERCHANT_PRIVATE_POST_ORDERS_ALREADY_EXISTS,
-        oc->parse_order.order_id);
-      return;
-    }
-  }
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Executing database transaction to create order '%s' for instance '%s'\n",
               oc->parse_order.order_id,
@@ -865,6 +846,37 @@ execute_order (struct OrderContext *oc)
     return;
   }
 
+  /* DB transaction succeeded, check for idempotent */
+  if (oc->execute_order.idempotent)
+  {
+    MHD_RESULT ret;
+
+    ret = TALER_MHD_REPLY_JSON_PACK (
+      oc->connection,
+      MHD_HTTP_OK,
+      GNUNET_JSON_pack_string ("order_id",
+                               oc->parse_order.order_id),
+      GNUNET_JSON_pack_allow_null (
+        GNUNET_JSON_pack_data_varsize (
+          "token",
+          GNUNET_is_zero (&oc->execute_order.token)
+          ? NULL
+          : &oc->execute_order.token,
+          sizeof (oc->execute_order.token))));
+    finalize_order (oc,
+                    ret);
+    return;
+  }
+  if (oc->execute_order.conflict)
+  {
+    reply_with_error (
+      oc,
+      MHD_HTTP_CONFLICT,
+      TALER_EC_MERCHANT_PRIVATE_POST_ORDERS_ALREADY_EXISTS,
+      oc->parse_order.order_id);
+    return;
+  }
+
   /* DB transaction succeeded, check for out-of-stock */
   if (oc->execute_order.out_of_stock_index < UINT_MAX)
   {
@@ -1261,6 +1273,47 @@ get_exchange_keys (void *cls,
 static void
 serialize_order (struct OrderContext *oc)
 {
+  const struct TALER_MERCHANTDB_InstanceSettings *settings =
+    &oc->hc->instance->settings;
+  json_t *merchant;
+
+  merchant = GNUNET_JSON_PACK (
+    GNUNET_JSON_pack_string ("name",
+                             settings->name),
+    GNUNET_JSON_pack_allow_null (
+      GNUNET_JSON_pack_string ("website",
+                               settings->website)),
+    GNUNET_JSON_pack_allow_null (
+      GNUNET_JSON_pack_string ("email",
+                               settings->email)),
+    GNUNET_JSON_pack_allow_null (
+      GNUNET_JSON_pack_string ("logo",
+                               settings->logo)));
+  GNUNET_assert (NULL != merchant);
+  {
+    json_t *loca = settings->address;
+
+    if (NULL != loca)
+    {
+      GNUNET_assert (0 ==
+                     json_object_set (merchant,
+                                      "address",
+                                      loca));
+    }
+  }
+  {
+    json_t *juri = settings->jurisdiction;
+
+    /* Handle merchant jurisdiction */
+    if (NULL != juri)
+    {
+      GNUNET_assert (0 ==
+                     json_object_set (merchant,
+                                      "jurisdiction",
+                                      juri));
+    }
+  }
+
   oc->serialize_order.contract = GNUNET_JSON_PACK (
     GNUNET_JSON_pack_string ("summary",
                              oc->parse_order.summary),
@@ -1279,6 +1332,9 @@ serialize_order (struct OrderContext *oc)
     GNUNET_JSON_pack_allow_null (
       GNUNET_JSON_pack_string ("fulfillment_url",
                                oc->parse_order.fulfillment_url)),
+    GNUNET_JSON_pack_allow_null (
+      GNUNET_JSON_pack_uint64 ("minimum_age",
+                               oc->parse_order.minimum_age)),
     GNUNET_JSON_pack_array_incref ("products",
                                    oc->merge_inventory.products),
     GNUNET_JSON_pack_data_auto ("h_wire",
@@ -1301,8 +1357,8 @@ serialize_order (struct OrderContext *oc)
                                       oc->parse_order.delivery_location)),
     GNUNET_JSON_pack_string ("merchant_base_url",
                              oc->parse_order.merchant_base_url),
-    GNUNET_JSON_pack_object_incref ("merchant",
-                                    oc->parse_order.merchant),
+    GNUNET_JSON_pack_object_steal ("merchant",
+                                   merchant),
     GNUNET_JSON_pack_data_auto ("merchant_pub",
                                 &oc->hc->instance->merchant_pub),
     GNUNET_JSON_pack_array_incref ("exchanges",
@@ -1532,6 +1588,10 @@ parse_order (struct OrderContext *oc)
       GNUNET_JSON_spec_timestamp ("delivery_date",
                                   &oc->parse_order.delivery_date),
       NULL),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_uint32 ("minimum_age",
+                               &oc->parse_order.minimum_age),
+      NULL),
     GNUNET_JSON_spec_mark_optional (
       GNUNET_JSON_spec_relative_time ("auto_refund",
                                       &oc->parse_order.auto_refund),
@@ -1833,53 +1893,6 @@ parse_order (struct OrderContext *oc)
     return;
   }
 
-  {
-    oc->parse_order.merchant = GNUNET_JSON_PACK (
-      GNUNET_JSON_pack_string ("name",
-                               settings->name),
-      GNUNET_JSON_pack_allow_null (
-        GNUNET_JSON_pack_string ("website",
-                                 settings->website)),
-      GNUNET_JSON_pack_allow_null (
-        GNUNET_JSON_pack_string ("email",
-                                 settings->email)),
-      GNUNET_JSON_pack_allow_null (
-        GNUNET_JSON_pack_string ("logo",
-                                 settings->logo)));
-    GNUNET_assert (NULL != oc->parse_order.merchant);
-    {
-      json_t *loca;
-
-      /* Handle merchant address */
-      loca = settings->address;
-      if (NULL != loca)
-      {
-        loca = json_deep_copy (loca);
-        GNUNET_assert (NULL != loca);
-        GNUNET_assert (0 ==
-                       json_object_set_new (oc->parse_order.merchant,
-                                            "address",
-                                            loca));
-      }
-    }
-    {
-      json_t *juri;
-
-      /* Handle merchant jurisdiction */
-      juri = settings->jurisdiction;
-      if (NULL != juri)
-      {
-        juri = json_deep_copy (juri);
-        GNUNET_assert (NULL != juri);
-        GNUNET_assert (0 ==
-                       json_object_set_new (oc->parse_order.merchant,
-                                            "jurisdiction",
-                                            juri));
-      }
-    }
-  }
-
-  oc->parse_order.merchant_pub = oc->hc->instance->merchant_pub;
   if ( (NULL != oc->parse_order.delivery_location) &&
        (! TMH_location_object_valid (oc->parse_order.delivery_location)) )
   {
@@ -2000,6 +2013,9 @@ merge_inventory (struct OrderContext *oc)
                           ip->product_id);
         return;
       }
+      oc->parse_order.minimum_age
+        = GNUNET_MAX (oc->parse_order.minimum_age,
+                      pd.minimum_age);
       {
         json_t *p;
 
@@ -2178,9 +2194,22 @@ parse_request (struct OrderContext *oc)
   /* parse the inventory_products (optionally given) */
   if (NULL != ip)
   {
+    unsigned int ipl = (unsigned int) json_array_size (ip);
+
+    if ( (json_array_size (ip) != (size_t) ipl) ||
+         (ipl > MAX_PRODUCTS) )
+    {
+      GNUNET_break (0);
+      GNUNET_JSON_parse_free (spec);
+      reply_with_error (oc,
+                        MHD_HTTP_INTERNAL_SERVER_ERROR,
+                        TALER_EC_GENERIC_ALLOCATION_FAILURE,
+                        "inventory products too long");
+      return;
+    }
     GNUNET_array_grow (oc->parse_request.inventory_products,
                        oc->parse_request.inventory_products_length,
-                       json_array_size (ip));
+                       (unsigned int) json_array_size (ip));
     for (unsigned int i = 0; i<oc->parse_request.inventory_products_length; i++)
     {
       struct InventoryProduct *ipr = &oc->parse_request.inventory_products[i];
