@@ -93,9 +93,8 @@ TMH_private_post_products (const struct TMH_RequestHandler *rh,
       NULL),
     GNUNET_JSON_spec_string ("unit",
                              (const char **) &pd.unit),
-    TALER_JSON_spec_amount ("price",
-                            TMH_currency,
-                            &pd.price),
+    TALER_JSON_spec_amount_any ("price",
+                                &pd.price),
     GNUNET_JSON_spec_mark_optional (
       GNUNET_JSON_spec_string ("image",
                                (const char **) &pd.image),
