@@ -45,7 +45,7 @@ static struct WorkResponse *w_tail;
 static struct GNUNET_DB_EventHandler *eh;
 
 /**
- * The exchange's configuration.
+ * The merchant's configuration.
  */
 static const struct GNUNET_CONFIGURATION_Handle *cfg;
 
@@ -183,9 +183,7 @@ handle_webhook_response (void *cls,
     case GNUNET_DB_STATUS_HARD_ERROR:
     case GNUNET_DB_STATUS_SOFT_ERROR:
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                  "Failed!\n");
-      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                  "Delete returned: %d\n",
+                  "Failed to delete webhook, delete returned: %d\n",
                   qs);
       global_ret = EXIT_FAILURE;
       GNUNET_SCHEDULER_shutdown ();
@@ -232,10 +230,9 @@ handle_webhook_response (void *cls,
     case GNUNET_DB_STATUS_HARD_ERROR:
     case GNUNET_DB_STATUS_SOFT_ERROR:
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                  "Failed!\n");
-      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                  "Next in %s Rval: %d\n",
-                  GNUNET_TIME_relative2s (next_attempt, true),
+                  "Failed to update pending webhook to next in %s Rval: %d\n",
+                  GNUNET_TIME_relative2s (next_attempt,
+                                          true),
                   qs);
       global_ret = EXIT_FAILURE;
       GNUNET_SCHEDULER_shutdown ();
@@ -441,7 +438,7 @@ select_work (void *cls)
   case GNUNET_DB_STATUS_HARD_ERROR:
   case GNUNET_DB_STATUS_SOFT_ERROR:
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                "Failed!\n");
+                "Failed to lookup pending webhooks!\n");
     global_ret = EXIT_FAILURE;
     GNUNET_SCHEDULER_shutdown ();
     return;
@@ -459,7 +456,7 @@ select_work (void *cls)
     case GNUNET_DB_STATUS_HARD_ERROR:
     case GNUNET_DB_STATUS_SOFT_ERROR:
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                  "Failed!\n");
+                  "Failed to lookup future webhook!\n");
       global_ret = EXIT_FAILURE;
       GNUNET_SCHEDULER_shutdown ();
       return;
@@ -467,20 +464,9 @@ select_work (void *cls)
       return;
     case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
       /* wait 5 min */
+      /* Note: this should not even be necessary if all webhooks
+         use the events properly... */
       rel = GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_MINUTES, 5);
-      if (NULL == eh)
-      {
-        struct GNUNET_DB_EventHeaderP es = {
-          .size = htons (sizeof (es)),
-          .type = htons (TALER_DBEVENT_MERCHANT_WEBHOOK_PENDING)
-        };
-
-        eh = db_plugin->event_listen (db_plugin->cls,
-                                      &es,
-                                      GNUNET_TIME_UNIT_FOREVER_REL,
-                                      &db_notify,
-                                      NULL);
-      }
       task = GNUNET_SCHEDULER_add_delayed (rel,
                                            &select_work,
                                            NULL);
@@ -493,7 +479,7 @@ select_work (void *cls)
 }
 
 
-/*
+/**
  * First task.
  *
  * @param cls closure, NULL
@@ -520,6 +506,7 @@ run (void *cls,
   {
     GNUNET_break (0);
     GNUNET_SCHEDULER_shutdown ();
+    global_ret = EXIT_NO_RESTART;
     return;
   }
   if (NULL ==
@@ -528,6 +515,7 @@ run (void *cls,
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Failed to initialize DB subsystem\n");
     GNUNET_SCHEDULER_shutdown ();
+    global_ret = EXIT_NOTCONFIGURED;
     return;
   }
   if (GNUNET_OK !=
@@ -536,8 +524,21 @@ run (void *cls,
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Failed to connect to database\n");
     GNUNET_SCHEDULER_shutdown ();
+    global_ret = EXIT_NO_RESTART;
     return;
   }
+  {
+    struct GNUNET_DB_EventHeaderP es = {
+      .size = htons (sizeof (es)),
+      .type = htons (TALER_DBEVENT_MERCHANT_WEBHOOK_PENDING)
+    };
+
+    eh = db_plugin->event_listen (db_plugin->cls,
+                                  &es,
+                                  GNUNET_TIME_UNIT_FOREVER_REL,
+                                  &db_notify,
+                                  NULL);
+  }
   GNUNET_assert (NULL == task);
   task = GNUNET_SCHEDULER_add_now (&select_work,
                                    NULL);
@@ -559,6 +560,8 @@ main (int argc,
                                "test",
                                "run in test mode and exit when idle",
                                &test_mode),
+    GNUNET_GETOPT_option_timetravel ('T',
+                                     "timetravel"),
     GNUNET_GETOPT_option_version (VERSION "-" VCS_VERSION),
     GNUNET_GETOPT_OPTION_END
   };
@@ -585,4 +588,4 @@ main (int argc,
 }
 
 
-/* end of taler-exchange-transfer.c */
+/* end of taler-merchant-webhook.c */
