@@ -43,6 +43,8 @@ TALER_MERCHANTDB_template_details_free (
 {
   GNUNET_free (tp->template_description);
   GNUNET_free (tp->otp_id);
+  GNUNET_free (tp->required_currency);
+  json_decref (tp->editable_defaults);
   json_decref (tp->template_contract);
 }
 
@@ -69,6 +71,7 @@ TALER_MERCHANTDB_pending_webhook_details_free (
   GNUNET_free (pwb->body);
 }
 
+
 void
 TALER_MERCHANTDB_token_family_details_free (
   struct TALER_MERCHANTDB_TokenFamilyDetails *tf)
