@@ -315,9 +315,10 @@ TALER_TESTING_cmd_merchant_delete_instance (const char *label,
  * @param image base64-encoded product image
  * @param taxes list of taxes paid by the merchant
  * @param total_stock in @a units, -1 to indicate "infinite" (i.e. electronic books)
+ * @param minimum_age minimum age required for buying this product
  * @param address where the product is in stock
  * @param next_restock when the next restocking is expected to happen, 0 for unknown,
- *                     #GNUNET_TIME_UNIT_FOREVER_ABS for 'never'.
+ *                     #GNUNET_TIME_UNIT_FOREVER_TS for 'never'.
  * @param http_status expected HTTP response code.
  * @return the command.
  */
@@ -333,6 +334,7 @@ TALER_TESTING_cmd_merchant_post_products2 (
   const char *image,
   json_t *taxes,
   int64_t total_stock,
+  uint32_t minimum_age,
   json_t *address,
   struct GNUNET_TIME_Timestamp next_restock,
   unsigned int http_status);
@@ -865,6 +867,27 @@ TALER_TESTING_cmd_merchant_get_order3 (
   unsigned int expected_http_status);
 
 
+/**
+ * Define a GET /private/orders/$ORDER_ID CMD.
+ *
+ * @param label the command label
+ * @param merchant_url base URL of the merchant which will
+ *        serve the request.
+ * @param order_reference reference to a command that created an order.
+ * @param osc expected order status
+ * @param expected_min_age expected minimum age for the contract
+ * @param expected_http_status expected HTTP response code for the request.
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_get_order4 (
+  const char *label,
+  const char *merchant_url,
+  const char *order_reference,
+  enum TALER_MERCHANT_OrderStatusCode osc,
+  uint32_t expected_min_age,
+  unsigned int expected_http_status);
+
+
 /**
  * Start a long poll for GET /private/orders/$ORDER_ID.
  */
