@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2020-2021 Taler Systems SA
+  Copyright (C) 2020-2024 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
@@ -159,7 +159,7 @@ handle_post_products_finished (void *cls,
 
 
 struct TALER_MERCHANT_ProductsPostHandle *
-TALER_MERCHANT_products_post (
+TALER_MERCHANT_products_post2 (
   struct GNUNET_CURL_Context *ctx,
   const char *backend_url,
   const char *product_id,
@@ -172,6 +172,7 @@ TALER_MERCHANT_products_post (
   int64_t total_stock,
   const json_t *address,
   struct GNUNET_TIME_Timestamp next_restock,
+  uint32_t minimum_age,
   TALER_MERCHANT_ProductsPostCallback cb,
   void *cb_cls)
 {
@@ -183,20 +184,26 @@ TALER_MERCHANT_products_post (
                              product_id),
     GNUNET_JSON_pack_string ("description",
                              description),
-    GNUNET_JSON_pack_object_incref ("description_i18n",
-                                    (json_t *) description_i18n),
+    GNUNET_JSON_pack_allow_null (
+      GNUNET_JSON_pack_object_incref ("description_i18n",
+                                      (json_t *) description_i18n)),
     GNUNET_JSON_pack_string ("unit",
                              unit),
     TALER_JSON_pack_amount ("price",
                             price),
     GNUNET_JSON_pack_string ("image",
                              image),
-    GNUNET_JSON_pack_array_incref ("taxes",
-                                   (json_t *) taxes),
+    GNUNET_JSON_pack_allow_null (
+      GNUNET_JSON_pack_array_incref ("taxes",
+                                     (json_t *) taxes)),
     GNUNET_JSON_pack_uint64 ("total_stock",
                              total_stock),
-    GNUNET_JSON_pack_object_incref ("address",
-                                    (json_t *) address),
+    GNUNET_JSON_pack_allow_null (
+      GNUNET_JSON_pack_uint64 ("minimum_age",
+                               minimum_age)),
+    GNUNET_JSON_pack_allow_null (
+      GNUNET_JSON_pack_object_incref ("address",
+                                      (json_t *) address)),
     GNUNET_JSON_pack_allow_null (
       GNUNET_JSON_pack_timestamp ("next_restock",
                                   next_restock)));
@@ -235,6 +242,41 @@ TALER_MERCHANT_products_post (
 }
 
 
+struct TALER_MERCHANT_ProductsPostHandle *
+TALER_MERCHANT_products_post (
+  struct GNUNET_CURL_Context *ctx,
+  const char *backend_url,
+  const char *product_id,
+  const char *description,
+  const json_t *description_i18n,
+  const char *unit,
+  const struct TALER_Amount *price,
+  const char *image,
+  const json_t *taxes,
+  int64_t total_stock,
+  const json_t *address,
+  struct GNUNET_TIME_Timestamp next_restock,
+  TALER_MERCHANT_ProductsPostCallback cb,
+  void *cb_cls)
+{
+  return TALER_MERCHANT_products_post2 (ctx,
+                                        backend_url,
+                                        product_id,
+                                        description,
+                                        description_i18n,
+                                        unit,
+                                        price,
+                                        image,
+                                        taxes,
+                                        total_stock,
+                                        address,
+                                        next_restock,
+                                        0,
+                                        cb,
+                                        cb_cls);
+}
+
+
 void
 TALER_MERCHANT_products_post_cancel (
   struct TALER_MERCHANT_ProductsPostHandle *pph)
