@@ -599,6 +599,20 @@ run (void *cls,
                                               "a product",
                                               "EUR:1",
                                               MHD_HTTP_NO_CONTENT),
+    TALER_TESTING_cmd_merchant_post_products2 ("post-products-p4",
+                                               merchant_url,
+                                               "product-4age",
+                                               "an age-restricted product",
+                                               NULL,
+                                               "unit",
+                                               "EUR:1",
+                                               "", /* image */
+                                               NULL,
+                                               4,
+                                               16 /* minimum age */,
+                                               NULL,
+                                               GNUNET_TIME_UNIT_FOREVER_TS,
+                                               MHD_HTTP_NO_CONTENT),
     TALER_TESTING_cmd_merchant_patch_product ("patch-products-p3",
                                               merchant_url,
                                               "product-3",
@@ -673,6 +687,25 @@ run (void *cls,
                                              "product-3/3",
                                              "lock-product-p3",
                                              NULL),
+    TALER_TESTING_cmd_merchant_post_orders2 ("create-proposal-p4-age",
+                                             cred.cfg,
+                                             merchant_url,
+                                             MHD_HTTP_OK,
+                                             "order-p4-age",
+                                             GNUNET_TIME_UNIT_ZERO_TS,
+                                             GNUNET_TIME_UNIT_FOREVER_TS,
+                                             false,
+                                             "EUR:5.0",
+                                             "x-taler-bank",
+                                             "product-4age",
+                                             "", /* locks */
+                                             NULL),
+    TALER_TESTING_cmd_merchant_get_order4 ("get-order-merchant-p4-age",
+                                           merchant_url,
+                                           "create-proposal-p4-age",
+                                           TALER_MERCHANT_OSC_CLAIMED,
+                                           16,
+                                           MHD_HTTP_OK),
     TALER_TESTING_cmd_merchant_delete_order ("delete-order-paid",
                                              merchant_url,
                                              "1",
