@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2014-2023 Taler Systems SA
+  Copyright (C) 2014-2024 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as
@@ -536,19 +536,20 @@ orders_run2 (void *cls,
                          locks_length,
                          uuid);
   }
-  ps->po = TALER_MERCHANT_orders_post2 (TALER_TESTING_interpreter_get_context (
-                                          is),
-                                        ps->merchant_url,
-                                        order,
-                                        GNUNET_TIME_UNIT_ZERO,
-                                        ps->payment_target,
-                                        products_length,
-                                        products,
-                                        locks_length,
-                                        locks,
-                                        ps->make_claim_token,
-                                        &order_cb,
-                                        ps);
+  ps->po = TALER_MERCHANT_orders_post2 (
+    TALER_TESTING_interpreter_get_context (
+      is),
+    ps->merchant_url,
+    order,
+    GNUNET_TIME_UNIT_ZERO,
+    ps->payment_target,
+    products_length,
+    products,
+    locks_length,
+    locks,
+    ps->make_claim_token,
+    &order_cb,
+    ps);
   GNUNET_free (products_string);
   GNUNET_free (locks_string);
   GNUNET_array_grow (products,
@@ -687,7 +688,6 @@ TALER_TESTING_cmd_merchant_post_orders_no_claim (
   ps->http_status = http_status;
   ps->expected_order_id = order_id;
   ps->merchant_url = merchant_url;
-  ps->with_claim = false;
   {
     struct TALER_TESTING_Command cmd = {
       .cls = ps,
@@ -786,3 +786,45 @@ TALER_TESTING_cmd_merchant_post_orders2 (
     return cmd;
   }
 }
+
+
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_merchant_post_orders3 (
+  const char *label,
+  const struct GNUNET_CONFIGURATION_Handle *cfg,
+  const char *merchant_url,
+  unsigned int expected_http_status,
+  const char *order_id,
+  struct GNUNET_TIME_Timestamp refund_deadline,
+  struct GNUNET_TIME_Timestamp pay_deadline,
+  const char *fulfillment_url,
+  const char *amount)
+{
+  struct OrdersState *ps;
+
+  ps = GNUNET_new (struct OrdersState);
+  ps->cfg = cfg;
+  make_order_json (order_id,
+                   refund_deadline,
+                   pay_deadline,
+                   amount,
+                   &ps->order_terms);
+  GNUNET_assert (0 ==
+                 json_object_set_new (ps->order_terms,
+                                      "fulfillment_url",
+                                      json_string (fulfillment_url)));
+  ps->http_status = expected_http_status;
+  ps->merchant_url = merchant_url;
+  ps->with_claim = true;
+  {
+    struct TALER_TESTING_Command cmd = {
+      .cls = ps,
+      .label = label,
+      .run = &orders_run,
+      .cleanup = &orders_cleanup,
+      .traits = &orders_traits
+    };
+
+    return cmd;
+  }
+}
