@@ -94,6 +94,11 @@ struct PostProductsState
    */
   json_t *address;
 
+  /**
+   * Minimum age requirement to use for the product.
+   */
+  unsigned int minimum_age;
+
   /**
    * when the next restocking is expected to happen, 0 for unknown,
    */
@@ -168,7 +173,7 @@ post_products_run (void *cls,
   struct PostProductsState *pis = cls;
 
   pis->is = is;
-  pis->iph = TALER_MERCHANT_products_post (
+  pis->iph = TALER_MERCHANT_products_post2 (
     TALER_TESTING_interpreter_get_context (is),
     pis->merchant_url,
     pis->product_id,
@@ -181,6 +186,7 @@ post_products_run (void *cls,
     pis->total_stock,
     pis->address,
     pis->next_restock,
+    pis->minimum_age,
     &post_products_cb,
     pis);
   GNUNET_assert (NULL != pis->iph);
@@ -197,7 +203,7 @@ post_products_run (void *cls,
  * @param index index number of the object to extract.
  * @return #GNUNET_OK on success
  */
-static int
+static enum GNUNET_GenericReturnValue
 post_products_traits (void *cls,
                       const void **ret,
                       const char *trait,
@@ -265,6 +271,7 @@ TALER_TESTING_cmd_merchant_post_products2 (
   const char *image,
   json_t *taxes,
   int64_t total_stock,
+  uint32_t minimum_age,
   json_t *address,
   struct GNUNET_TIME_Timestamp next_restock,
   unsigned int http_status)
@@ -288,6 +295,7 @@ TALER_TESTING_cmd_merchant_post_products2 (
   pis->image = GNUNET_strdup (image);
   pis->taxes = taxes; /* ownership taken */
   pis->total_stock = total_stock;
+  pis->minimum_age = minimum_age;
   pis->address = address; /* ownership taken */
   pis->next_restock = next_restock;
   {
@@ -305,12 +313,13 @@ TALER_TESTING_cmd_merchant_post_products2 (
 
 
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_merchant_post_products (const char *label,
-                                          const char *merchant_url,
-                                          const char *product_id,
-                                          const char *description,
-                                          const char *price,
-                                          unsigned int http_status)
+TALER_TESTING_cmd_merchant_post_products (
+  const char *label,
+  const char *merchant_url,
+  const char *product_id,
+  const char *description,
+  const char *price,
+  unsigned int http_status)
 {
   return TALER_TESTING_cmd_merchant_post_products2 (
     label,
@@ -322,7 +331,8 @@ TALER_TESTING_cmd_merchant_post_products (const char *label,
     price,
     "",
     json_array (),
-    4,
+    4, /* total stock */
+    0, /* minimum age */
     json_pack ("{s:s}", "street", "my street"),
     GNUNET_TIME_UNIT_ZERO_TS,
     http_status);
